@@ -102,7 +102,7 @@ if ($errors) {
 my @thrd;
 
 $threads /= scalar(@devs);
-$threads = min(20,$threads);
+$threads = min(20,$threads); # enforce a 20 thread hard limit
 
 # Run the slides in threads and have the main thread do housekeeping.
 my $showit = $splash;
@@ -159,12 +159,17 @@ sub gather {
     my @pics;
     foreach my $path (@paths) {
         chop($path) if ($path =~ /\/$/);
-        print STDOUT "Scanning - $path\n";
+        print STDERR "Scanning - $path";
         opendir(my $DIR, "$path") || die "Problem reading $path directory";
         chomp(my @dir = readdir($DIR));
         closedir($DIR);
 
-        return if (!$showall && grep(/^\.nomedia$/, @dir));
+        if (!$showall && grep(/^\.nomedia$/, @dir)) {
+            print STDERR " [Skipped]\n";
+            return;
+        } else {
+            print STDERR "\n";
+        }
         foreach my $file (@dir) {
             next if ($file =~ /^\.+/);
             if (-d "$path/$file") {
